**************************************************************************************************.
*     Program: Read_PSU_05.sps                                                                   *.
*        Note: 1) This program reads in the following three 2005-2006 nonfiscal CCD              *.
*                 school data files and creates a SAS system data file:                          *.
*                   a) SC051AAI.TXT - States A-I  (Alabama - Iowa)                               *.
*                   b) SC051AKN.TXT - States K-N  (Kansas - North Dakota)                        *. 
*                   c) SC051AOW.TXT - States O-W  (Ohio - Wyoming)                               *.
*                   *  Other jurisdictions are included in the files.                            *.
*              2) Change the file paths as indicated below for the location of the input         *.
*                 and output files respectively.                                                 *.
*   Provided by: National Center for Education Statistics                                        *.
*  Last updated: June 5, 2007                                                                    *.
**************************************************************************************************.

*** Change the file paths below for the location of your input and output files  ***.

*** For input data files SC051AAI.TXT, SC051AKN.TXT, and SC051AOW.TXT ***.
DEFINE ai_in ()
  'h:\ccd\data\nf\y0506\1a\school\data\sc051aai.dat' /* <--- change the path here */
!ENDDEFINE.

DEFINE kn_in ()
  'h:\ccd\data\nf\y0506\1a\school\data\sc051akn.dat' /* <--- change the path here */
!ENDDEFINE.

DEFINE ow_in ()
  'h:\ccd\data\nf\y0506\1a\school\data\sc051aow.dat' /* <--- change the path here */
!ENDDEFINE.

*** FOR SPSS OUTPUT FILES ***.
DEFINE ai_out ()
  'h:\ccd\data\sc051aai.sav' /* <--- change the path here */
!ENDDEFINE.
DEFINE kn_out ()
  'h:\ccd\data\sc051akn.sav' /* <--- change the path here */
!ENDDEFINE.
DEFINE ow_out ()
  'h:\ccd\data\sc051aow.sav' /* <--- change the path here */
!ENDDEFINE.
DEFINE sc051a ()
  'h:\ccd\data\sc051a.sav'   /* <--- change the path here */
!ENDDEFINE.

***********************************************************.
***    DO NOT MAKE ANY CHANGE BELOW UNLESS NECESSARY    ***.
***********************************************************.
DEFINE varlist ()
NCESSCH		0001-0012		(A)
FIPST			0001-0002		(A)
LEAID			0001-0007		(A)
SCHNO			0008-0012		(A)
STID05		0013-0026		(A)
SEASCH05		0027-0046		(A)
LEANM05		0047-0106		(A)
SCHNAM05		0107-0156		(A)
PHONE05		0157-0166		(A)
MSTREE05		0167-0196		(A)
MCITY05		0197-0226		(A)
MSTATE05		0227-0228		(A)
MZIP05		0229-0233		(A)
MZIP405		0234-0237		(A)
LSTREE05		0238-0267		(A)
LCITY05		0268-0297		(A)
LSTATE05		0298-0299		(A)
LZIP05		0300-0304		(A)
LZIP405		0305-0308		(A)
TYPE05		0309-0309		(A)
STATUS05		0310-0310		(A)
LOCALE05		0311-0311		(A)
INOUT05		0312-0312		(A)
LATCOD05		0313-0322		(A)
LONCOD05		0323-0332		(A)
CONUM05		0333-0337		(A)
CONAME05		0338-0367		(A)
FTE05			0368-0372		(F,1)
GSLO05		0373-0374		(A)
GSHI05		0375-0376		(A)
LEVEL05		0377-0377		(A)
TITLEI05		0378-0378		(A)
STITLI05		0379-0379		(A)
MAGNET05		0380-0380		(A)
CHARTR05		0381-0381		(A)
SHARED05		0382-0382		(A)
FRELCH05		0383-0386		(F)
REDLCH05		0387-0390		(F)
TOTFRL05		0391-0394		(F)
MIGRNT05		0395-0398		(F)
PK05			0399-0402		(F)
AMPKM05		0403-0406		(F)
AMPKF05		0407-0410		(F)
AMPKU05		0411-0414		(F)
ASPKM05		0415-0418		(F)
ASPKF05		0419-0422		(F)
ASPKU05		0423-0426		(F)
HIPKM05		0427-0430		(F)
HIPKF05		0431-0434		(F)
HIPKU05		0435-0438		(F)
BLPKM05		0439-0442		(F)
BLPKF05		0443-0446		(F)
BLPKU05		0447-0450		(F)
WHPKM05		0451-0454		(F)
WHPKF05		0455-0458		(F)
WHPKU05		0459-0462		(F)
KG05			0463-0466		(F)
AMKGM05		0467-0470		(F)
AMKGF05		0471-0474		(F)
AMKGU05		0475-0478		(F)
ASKGM05		0479-0482		(F)
ASKGF05		0483-0486		(F)
ASKGU05		0487-0490		(F)
HIKGM05		0491-0494		(F)
HIKGF05		0495-0498		(F)
HIKGU05		0499-0502		(F)
BLKGM05		0503-0506		(F)
BLKGF05		0507-0510		(F)
BLKGU05		0511-0514		(F)
WHKGM05		0515-0518		(F)
WHKGF05		0519-0522		(F)
WHKGU05		0523-0526		(F)
G0105			0527-0530		(F)
AM01M05		0531-0534		(F)
AM01F05		0535-0538		(F)
AM01U05		0539-0542		(F)
AS01M05		0543-0546		(F)
AS01F05		0547-0550		(F)
AS01U05		0551-0554		(F)
HI01M05		0555-0558		(F)
HI01F05		0559-0562		(F)
HI01U05		0563-0566		(F)
BL01M05		0567-0570		(F)
BL01F05		0571-0574		(F)
BL01U05		0575-0578		(F)
WH01M05		0579-0582		(F)
WH01F05		0583-0586		(F)
WH01U05		0587-0590		(F)
G0205			0591-0594		(F)
AM02M05		0595-0598		(F)
AM02F05		0599-0602		(F)
AM02U05		0603-0606		(F)
AS02M05		0607-0610		(F)
AS02F05		0611-0614		(F)
AS02U05		0615-0618		(F)
HI02M05		0619-0622		(F)
HI02F05		0623-0626		(F)
HI02U05		0626-0630		(F)
BL02M05		0631-0634		(F)
BL02F05		0635-0638		(F)
BL02U05		0639-0642		(F)
WH02M05		0643-0646		(F)
WH02F05		0647-0650		(F)
WH02U05		0651-0654		(F)
G0305			0655-0658		(F)
AM03M05		0659-0662		(F)
AM03F05		0663-0666		(F)
AM03U05		0667-0670		(F)
AS03M05		0671-0674		(F)
AS03F05		0675-0678		(F)
AS03U05		0679-0682		(F)
HI03M05		0683-0686		(F)
HI03F05		0687-0690		(F)
HI03U05		0691-0694		(F)
BL03M05		0695-0698		(F)
BL03F05		0699-0702		(F)
BL03U05		0703-0706		(F)
WH03M05		0707-0710		(F)
WH03F05		0711-0714		(F)
WH03U05		0715-0718		(F)
G0405			0719-0722		(F)
AM04M05		0723-0726		(F)
AM04F05		0727-0730		(F)
AM04U05		0731-0734		(F)
AS04M05		0735-0738		(F)
AS04F05		0739-0742		(F)
AS04U05		0743-0746		(F)
HI04M05		0747-0750		(F)
HI04F05		0751-0754		(F)
HI04U05		0755-0758		(F)
BL04M05		0759-0762		(F)
BL04F05		0763-0766		(F)
BL04U05		0767-0770		(F)
WH04M05		0771-0774		(F)
WH04F05		0775-0778		(F)
WH04U05		0779-0782		(F)
G0505			0783-0786		(F)
AM05M05		0787-0790		(F)
AM05F05		0791-0794		(F)
AM05U05		0795-0798		(F)
AS05M05		0799-0802		(F)
AS05F05		0803-0806		(F)
AS05U05		0807-0810		(F)
HI05M05		0811-0814		(F)
HI05F05		0815-0818		(F)
HI05U05		0819-0822		(F)
BL05M05		0823-0826		(F)
BL05F05		0827-0830		(F)
BL05U05		0831-0834		(F)
WH05M05		0835-0838		(F)
WH05F05		0839-0842		(F)
WH05U05		0843-0846		(F)
G0605			0847-0850		(F)
AM06M05		0851-0854		(F)
AM06F05		0855-0858		(F)
AM06U05		0859-0862		(F)
AS06M05		0863-0866		(F)
AS06F05		0867-0870		(F)
AS06U05		0871-0874		(F)
HI06M05		0875-0878		(F)
HI06F05		0879-0882		(F)
HI06U05		0883-0886		(F)
BL06M05		0887-0890		(F)
BL06F05		0891-0894		(F)
BL06U05		0895-0898		(F)
WH06M05		0899-0902		(F)
WH06F05		0903-0906		(F)
WH06U05		0907-0910		(F)
G0705			0911-0914		(F)
AM07M05		0915-0918		(F)
AM07F05		0919-0922		(F)
AM07U05		0923-0926		(F)
AS07M05		0927-0930		(F)
AS07F05		0931-0934		(F)
AS07U05		0935-0938		(F)
HI07M05		0939-0942		(F)
HI07F05		0943-0946		(F)
HI07U05		0947-0950		(F)
BL07M05		0951-0954		(F)
BL07F05		0955-0958		(F)
BL07U05		0959-0962		(F)
WH07M05		0963-0966		(F)
WH07F05		0967-0970		(F)
WH07U05		0971-0974		(F)
G0805			0975-0978		(F)
AM08M05		0979-0982		(F)
AM08F05		0983-0986		(F)
AM08U05		0987-0990		(F)
AS08M05		0991-0994		(F)
AS08F05		0995-0998		(F)
AS08U05		0999-1002		(F)
HI08M05		1003-1006		(F)
HI08F05		1007-1010		(F)
HI08U05		1011-1014		(F)
BL08M05		1015-1018		(F)
BL08F05		1019-1022		(F)
BL08U05		1023-1026		(F)
WH08M05		1027-1030		(F)
WH08F05		1031-1034		(F)
WH08U05		1035-1038		(F)
G0905			1039-1042		(F)
AM09M05		1043-1046		(F)
AM09F05		1047-1050		(F)
AM09U05		1051-1054		(F)
AS09M05		1055-1058		(F)
AS09F05		1059-1062		(F)
AS09U05		1063-1066		(F)
HI09M05		1067-1070		(F)
HI09F05		1071-1074		(F)
HI09U05		1075-1078		(F)
BL09M05		1079-1082		(F)
BL09F05		1083-1086		(F)
BL09U05		1087-1090		(F)
WH09M05		1091-1094		(F)
WH09F05		1095-1098		(F)
WH09U05		1099-1102		(F)
G1005			1103-1106		(F)
AM10M05		1107-1110		(F)
AM10F05		1111-1114		(F)
AM10U05		1115-1118		(F)
AS10M05		1119-1122		(F)
AS10F05		1123-1126		(F)
AS10U05		1127-1130		(F)
HI10M05		1131-1134		(F)
HI10F05		1135-1138		(F)
HI10U05		1139-1142		(F)
BL10M05		1143-1146		(F)
BL10F05		1147-1150		(F)
BL10U05		1151-1154		(F)
WH10M05		1155-1158		(F)
WH10F05		1159-1162		(F)
WH10U05		1163-1166		(F)
G1105			1167-1170		(F)
AM11M05		1171-1174		(F)
AM11F05		1175-1178		(F)
AM11U05		1179-1182		(F)
AS11M05		1183-1186		(F)
AS11F05		1187-1190		(F)
AS11U05		1191-1194		(F)
HI11M05		1195-1198		(F)
HI11F05		1199-1202		(F)
HI11U05		1203-1206		(F)
BL11M05		1207-1210		(F)
BL11F05		1211-1214		(F)
BL11U05		1215-1218		(F)
WH11M05		1219-1222		(F)
WH11F05		1223-1226		(F)
WH11U05		1227-1230		(F)
G1205			1231-1234		(F)
AM12M05		1235-1238		(F)
AM12F05		1239-1242		(F)
AM12U05		1243-1246		(F)
AS12M05		1247-1250		(F)
AS12F05		1251-1254		(F)
AS12U05		1255-1258		(F)
HI12M05		1259-1262		(F)
HI12F05		1263-1266		(F)
HI12U05		1267-1270		(F)
BL12M05		1271-1274		(F)
BL12F05		1275-1278		(F)
BL12U05		1279-1282		(F)
WH12M05		1283-1286		(F)
WH12F05		1287-1290		(F)
WH12U05		1291-1294		(F)
UG05			1295-1298		(F)
AMUGM05		1299-1302		(F)
AMUGF05		1303-1305		(F)
AMUGU05		1307-1310		(F)
ASUGM05		1311-1314		(F)
ASUGF05		1315-1318		(F)
ASUGU05		1319-1322		(F)
HIUGM05		1323-1326		(F)
HIUGF05		1327-1330		(F)
HIUGU05		1331-1334		(F)
BLUGM05		1335-1338		(F)
BLUGF05		1339-1342		(F)
BLUGU05		1343-1346		(F)
WHUGM05		1347-1350		(F)
WHUGF05		1351-1354		(F)
WHUGU05		1355-1358		(F)
MEMBER05		1359-1362		(F)
AM05			1363-1366		(F)
AMALM05		1367-1370		(F)
AMALF05		1371-1374		(F)
AMALU05		1375-1378		(F)
ASIAN05		1379-1382		(F)
ASALM05		1383-1386		(F)
ASALF05		1387-1390		(F)
ASALU05		1391-1394		(F)
HISP05		1395-1398		(F)
HIALM05		1399-1402		(F)
HIALF05		1403-1406		(F)
HIALU05		1407-1410		(F)
BLACK05		1411-1414		(F)
BLALM05		1415-1418		(F)
BLALF05		1419-1422		(F)
BLALU05		1423-1426		(F)
WHITE05		1427-1430		(F)
WHALM05		1431-1434		(F)
WHALF05		1435-1438		(F)
WHALU05		1439-1442		(F)
TOTETH05		1443-1446		(F)
PUPTCH05		1447-1451		(F,1)
TOTGRD05		1452-1455		(F)
ILOCAL05		1456-1456		(A)
IFTE05		1457-1457		(A)
IGSLO05		1458-1458		(A)
IGSHI05		1459-1459		(A)
ITITLI05		1460-1460		(A)
ISTITL05		1461-1461		(A)
IMAGNE05		1462-1462		(A)
ICHART05		1463-1463		(A)
ISHARE05		1464-1464		(A)
IFRELC05		1465-1465		(A)
IREDLC05		1466-1466		(A)
ITOTFR05		1467-1467		(A)
IMIGRN05		1468-1468		(A)
IPK05			1469-1469		(A)
IAMPKM05		1470-1470		(A)
IAMPKF05		1471-1471		(A)
IAMPKU05		1472-1472		(A)
IASPKM05		1473-1473		(A)
IASPKF05		1474-1474		(A)
IASPKU05		1475-1475		(A)
IHIPKM05		1476-1476		(A)
IHIPKF05		1477-1477		(A)
IHIPKU05		1478-1478		(A)
IBLPKM05		1479-1479		(A)
IBLPKF05		1480-1480		(A)
IBLPKU05		1481-1481		(A)
IWHPKM05		1482-1482		(A)
IWHPKF05		1483-1483		(A)
IWHPKU05		1484-1484		(A)
IKG05			1485-1485		(A)
IAMKGM05		1486-1486		(A)
IAMKGF05		1487-1487		(A)
IAMKGU05		1488-1488		(A)
IASKGM05		1489-1489		(A)
IASKGF05		1490-1490		(A)
IASKGU05		1491-1491		(A)
IHIKGM05		1492-1492		(A)
IHIKGF05		1493-1493		(A)
IHIKGU05		1494-1494		(A)
IBLKGM05		1495-1495		(A)
IBLKGF05		1496-1496		(A)
IBLKGU05		1497-1497		(A)
IWHKGM05		1498-1498		(A)
IWHKGF05		1499-1499		(A)
IWHKGU05		1500-1500		(A)
IG0105		1501-1501		(A)
IAM01M05		1502-1502		(A)
IAM01F05		1504-1504		(A)
IAM01U05		1505-1505		(A)
IAS01M05		1505-1505		(A)
IAS01F05		1506-1506		(A)
IAS01U05		1507-1507		(A)
IHI01M05		1508-1508		(A)
IHI01F05		1509-1509		(A)
IHI01U05		1510-1510		(A)
IBL01M05		1511-1511		(A)
IBL01F05		1512-1512		(A)
IBL01U05		1513-1513		(A)
IWH01M05		1514-1514		(A)
IWH01F05		1515-1515		(A)
IWH01U05		1516-1516		(A)
IG0205		1517-1517		(A)
IAM02M05		1518-1518		(A)
IAM02F05		1519-1519		(A)
IAM02U05		1520-1520		(A)
IAS02M05		1521-1521		(A)
IAS02F05		1522-1522		(A)
IAS02U05		1523-1523		(A)
IHI02M05		1524-1524		(A)
IHI02F05		1525-1525		(A)
IHI02U05		1526-1526		(A)
IBL02M05		1527-1527		(A)
IBL02F05		1528-1528		(A)
IBL02U05		1529-1529		(A)
IWH02M05		1530-1530		(A)
IWH02F05		1531-1531		(A)
IWH02U05		1532-1532		(A)
IG0305		1533-1533		(A)
IAM03M05		1534-1534		(A)
IAM03F05		1535-1535		(A)
IAM03U05		1536-1536		(A)
IAS03M05		1537-1537		(A)
IAS03F05		1538-1538		(A)
IAS03U05		1539-1539		(A)
IHI03M05		1540-1540		(A)
IHI03F05		1541-1541		(A)
IHI03U05		1542-1542		(A)
IBL03M05		1543-1543		(A)
IBL03F05		1544-1544		(A)
IBL03U05		1545-1545		(A)
IWH03M05		1546-1546		(A)
IWH03F05		1547-1547		(A)
IWH03U05		1548-1548		(A)
IG0405		1549-1549		(A)
IAM04M05		1550-1550		(A)
IAM04F05		1551-1551		(A)
IAM04U05		1552-1552		(A)
IAS04M05		1553-1553		(A)
IAS04F05		1554-1554		(A)
IAS04U05		1555-1555		(A)
IHI04M05		1556-1556		(A)
IHI04F05		1557-1557		(A)
IHI04U05		1558-1558		(A)
IBL04M05		1559-1559		(A)
IBL04F05		1560-1560		(A)
IBL04U05		1561-1561		(A)
IWH04M05		1562-1562		(A)
IWH04F05		1563-1563		(A)
IWH04U05		1564-1564		(A)
IG0505		1565-1565		(A)
IAM05M05		1566-1566		(A)
IAM05F05		1567-1567		(A)
IAM05U05		1568-1568		(A)
IAS05M05		1569-1569		(A)
IAS05F05		1570-1570		(A)
IAS05U05		1571-1571		(A)
IHI05M05		1572-1572		(A)
IHI05F05		1573-1573		(A)
IHI05U05		1574-1574		(A)
IBL05M05		1575-1575		(A)
IBL05F05		1576-1576		(A)
IBL05U05		1577-1577		(A)
IWH05M05		1578-1578		(A)
IWH05F05		1579-1579		(A)
IWH05U05		1580-1580		(A)
IG0605		1581-1581		(A)
IAM06M05		1582-1582		(A)
IAM06F05		1583-1583		(A)
IAM06U05		1584-1584		(A)
IAS06M05		1585-1585		(A)
IAS06F05		1586-1586		(A)
IAS06U05		1587-1587		(A)
IHI06M05		1588-1588		(A)
IHI06F05		1589-1589		(A)
IHI06U05		1590-1590		(A)
IBL06M05		1591-1591		(A)
IBL06F05		1592-1592		(A)
IBL06U05		1593-1593		(A)
IWH06M05		1594-1594		(A)
IWH06F05		1595-1595		(A)
IWH06U05		1596-1596		(A)
IG0705		1597-1597		(A)
IAM07M05		1598-1598		(A)
IAM07F05		1599-1599		(A)
IAM07U05		1600-1600		(A)
IAS07M05		1601-1601		(A)
IAS07F05		1602-1602		(A)
IAS07U05		1603-1603		(A)
IHI07M05		1605-1605		(A)
IHI07F05		1605-1605		(A)
IHI07U05		1606-1606		(A)
IBL07M05		1607-1607		(A)
IBL07F05		1608-1608		(A)
IBL07U05		1609-1609		(A)
IWH07M05		1610-1610		(A)
IWH07F05		1611-1611		(A)
IWH07U05		1612-1612		(A)
IG0805		1613-1613		(A)
IAM08M05		1614-1614		(A)
IAM08F05		1615-1615		(A)
IAM08U05		1616-1616		(A)
IAS08M05		1617-1617		(A)
IAS08F05		1618-1618		(A)
IAS08U05		1619-1619		(A)
IHI08M05		1620-1620		(A)
IHI08F05		1621-1621		(A)
IHI08U05		1622-1622		(A)
IBL08M05		1623-1623		(A)
IBL08F05		1624-1624		(A)
IBL08U05		1625-1625		(A)
IWH08M05		1626-1626		(A)
IWH08F05		1627-1627		(A)
IWH08U05		1628-1628		(A)
IG0905		1629-1629		(A)
IAM09M05		1630-1630		(A)
IAM09F05		1631-1631		(A)
IAM09U05		1632-1632		(A)
IAS09M05		1633-1633		(A)
IAS09F05		1634-1634		(A)
IAS09U05		1635-1635		(A)
IHI09M05		1636-1636		(A)
IHI09F05		1637-1637		(A)
IHI09U05		1638-1638		(A)
IBL09M05		1639-1639		(A)
IBL09F05		1640-1640		(A)
IBL09U05		1641-1641		(A)
IWH09M05		1642-1642		(A)
IWH09F05		1643-1643		(A)
IWH09U05		1644-1644		(A)
IG1005		1645-1645		(A)
IAM10M05		1646-1646		(A)
IAM10F05		1647-1647		(A)
IAM10U05		1648-1648		(A)
IAS10M05		1649-1649		(A)
IAS10F05		1650-1650		(A)
IAS10U05		1651-1651		(A)
IHI10M05		1652-1652		(A)
IHI10F05		1653-1653		(A)
IHI10U05		1654-1654		(A)
IBL10M05		1655-1655		(A)
IBL10F05		1656-1656		(A)
IBL10U05		1657-1657		(A)
IWH10M05		1658-1658		(A)
IWH10F05		1659-1659		(A)
IWH10U05		1660-1660		(A)
IG1105		1661-1661		(A)
IAM11M05		1662-1662		(A)
IAM11F05		1663-1663		(A)
IAM11U05		1664-1664		(A)
IAS11M05		1665-1665		(A)
IAS11F05		1666-1666		(A)
IAS11U05		1667-1667		(A)
IHI11M05		1668-1668		(A)
IHI11F05		1669-1669		(A)
IHI11U05		1670-1670		(A)
IBL11M05		1671-1671		(A)
IBL11F05		1672-1672		(A)
IBL11U05		1673-1673		(A)
IWH11M05		1674-1674		(A)
IWH11F05		1675-1675		(A)
IWH11U05		1676-1676		(A)
IG1205		1677-1677		(A)
IAM12M05		1678-1678		(A)
IAM12F05		1679-1679		(A)
IAM12U05		1680-1680		(A)
IAS12M05		1681-1681		(A)
IAS12F05		1682-1682		(A)
IAS12U05		1683-1683		(A)
IHI12M05		1684-1684		(A)
IHI12F05		1685-1685		(A)
IHI12U05		1686-1686		(A)
IBL12M05		1687-1687		(A)
IBL12F05		1688-1688		(A)
IBL12U05		1689-1689		(A)
IWH12M05		1690-1690		(A)
IWH12F05		1691-1691		(A)
IWH12U05		1692-1692		(A)
IUG05			1693-1693		(A)
IAMUGM05		1694-1694		(A)
IAMUGF05		1695-1695		(A)
IAMUGU05		1696-1696		(A)
IASUGM05		1697-1697		(A)
IASUGF05		1698-1698		(A)
IASUGU05		1699-1699		(A)
IHIUGM05		1700-1700		(A)
IHIUGF05		1701-1701		(A)
IHIUGU05		1702-1702		(A)
IBLUGM05		1703-1703		(A)
IBLUGF05		1705-1705		(A)
IBLUGU05		1705-1705		(A)
IWHUGM05		1706-1706		(A)
IWHUGF05		1707-1707		(A)
IWHUGU05		1708-1708		(A)
IMEMB05		1709-1709		(A)
IAM05			1710-1710		(A)
IAMALM05		1711-1711		(A)
IAMALF05		1712-1712		(A)
IAMALU05		1713-1713		(A)
IASIAN05		1714-1714		(A)
IASALM05		1715-1715		(A)
IASALF05		1716-1716		(A)
IASALU05		1717-1717		(A)
IHISP05		1718-1718		(A)
IHIALM05		1719-1719		(A)
IHIALF05		1720-1720		(A)
IHIALU05		1721-1721		(A)
IBLACK05		1722-1722		(A)
IBLALM05		1723-1723		(A)
IBLALF05		1724-1724		(A)
IBLALU05		1725-1725		(A)
IWHITE05		1726-1726		(A)
IWHALM05		1727-1727		(A)
IWHALF05		1728-1728		(A)
IWHALU05		1729-1729		(A)
IETH05		1730-1730		(A)
IPUTCH05		1731-1731		(A)
ITOTGR05		1732-1732		(A)
!ENDDEFINE.

*** Read in the three raw data files ***.
DATA LIST FILE= ai_in FIXED RECORDS  1 
/1
varlist.
SAVE OUTFILE ai_out/COMPRESS.
DATA LIST FILE= kn_in FIXED RECORDS  1 
/1
varlist.
SAVE OUTFILE kn_out/COMPRESS.
DATA LIST FILE= ow_in FIXED RECORDS  1 
/1
varlist.
SAVE OUTFILE ow_out/COMPRESS.

*****************************.
***   Combine the files   ***.
*****************************.
ADD FILES
  /FILE=ai_out
  /FILE=kn_out
  /FILE=ow_out.
EXECUTE.

FILE LABEL 'CCD.SCHOOL.2005-06 VERSION 1A'.

VARIABLE LABELS
NCESSCH		'NCES Unique School ID'
FIPST			'Fips State Numberic Code'
LEAID			'NCES Assigned Agency ID'
SCHNO			'NCES Assigned School ID'
STID05		'State Assigned Agency ID'
SEASCH05		'State Assigned School ID'
LEANM05		'Agency Name'
SCHNAM05		'School Name'
PHONE05		'School Telephone Number'
MSTREE05		'Mailing Address'
MCITY05		'Mailing City'
MSTATE05		'Mailing USPS State Abbreviation'
MZIP05		'Mailing 5-Digit ZIP Code'
MZIP405		'Mailing Zip Code Extention'
LSTREE05		'Location Address'
LCITY05		'Location City'
LSTATE05		'Location USPS State Abbreviation'
LZIP05		'Location 5-Digit ZIP Code'
LZIP405		'Location Zip Code Extention'
TYPE05		'School Type'
STATUS05		'Operational Status'
LOCALE05		'Locale Code'
INOUT05		'Location Relative to Town Limits Code'
LATCOD05		'Latitude Code'
LONCOD05		'Longitude Code'
CONUM05		'FIPS County Number'
CONAME05		'County Name'
FTE05			'Classroom Teachers (FTE)'
GSLO05		'School Lowest Grade Offered'
GSHI05		'School Highest Grade Offered'
LEVEL05		'School Level'
TITLEI05		'Title I Eligible School'
STITLI05		'School-wide Title I'
MAGNET05		'Magnet School'
CHARTR05		'Charter School'
SHARED05		'Shared-time School'
FRELCH05		'Free Lunch Eligible Students'
REDLCH05		'Reduced-price Lunch Eligible Students'
TOTFRL05		'Total Free and Reduced Lunch Students'
MIGRNT05		'Migrant Students'
PK05			'Students (Total PK Grade)'
AMPKM05		'Students (PK-Amer Ind/AK Nat-Male)'
AMPKF05		'Students (PK-Amer Ind/AK Nat-Female)'
AMPKU05		'Students (PK-Amer Ind/AK Nat-Unknown)'
ASPKM05		'Students (PK-Asian/Pac Isl-Male)'
ASPKF05		'Students (PK-Asian/Pac Isl-Female)'
ASPKU05		'Students (PK-Asian/Pac Isl-Unknown)'
HIPKM05		'Students (PK-Hispanic-Male)'
HIPKF05		'Students (PK-Hispanic-Female)'
HIPKU05		'Students (PK-Hispanic-Unknown)'
BLPKM05		'Students (PK-Black-Male)'
BLPKF05		'Students (PK-Black-Female)'
BLPKU05		'Students (PK-Black-Unknown)'
WHPKM05		'Students (PK-White-Male)'
WHPKF05		'Students (PK-White-Female)'
WHPKU05		'Students (PK-White-Unknown)'
KG05			'Students (Total KG Grade)'
AMKGM05		'Students (KG-Amer Ind/AK Nat-Male)'
AMKGF05		'Students (KG-Amer Ind/AK Nat-Female)'
AMKGU05		'Students (KG-Amer Ind/AK Nat-Unknown)'
ASKGM05		'Students (KG-Asian/Pac Isl-Male)'
ASKGF05		'Students (KG-Asian/Pac Isl-Female)'
ASKGU05		'Students (KG-Asian/Pac Isl-Unknown)'
HIKGM05		'Students (KG-Hispanic-Male)'
HIKGF05		'Students (KG-Hispanic-Female)'
HIKGU05		'Students (KG-Hispanic-Unknown)'
BLKGM05		'Students (KG-Black-Male)'
BLKGF05		'Students (KG-Black-Female)'
BLKGU05		'Students (KG-Black-Unknown)'
WHKGM05		'Students (KG-White-Male)'
WHKGF05		'Students (KG-White-Female)'
WHKGU05		'Students (KG-White-Unknown)'
G0105			'Students (Total 1st Grade)'
AM01M05		'Students (1st-Amer Ind/AK Nat-Male)'
AM01F05		'Students (1st-Amer Ind/AK Nat-Female)'
AM01U05		'Students (1st-Amer Ind/AK Nat-Unknown)'
AS01M05		'Students (1st-Asian/Pac Isl-Male)'
AS01F05		'Students (1st-Asian/Pac Isl-Female)'
AS01U05		'Students (1st-Asian/Pac Isl-Unknown)'
HI01M05		'Students (1st-Hispanic-Male)'
HI01F05		'Students (1st-Hispanic-Female)'
HI01U05		'Students (1st-Hispanic-Unknown)'
BL01M05		'Students (1st-Black-Male)'
BL01F05		'Students (1st-Black-Female)'
BL01U05		'Students (1st-Black-Unknown)'
WH01M05		'Students (1st-White-Male)'
WH01F05		'Students (1st-White-Female)'
WH01U05		'Students (1st-White-Unknown)'
G0205			'Students (Total 2nd Grade)'
AM02M05		'Students (2nd-Amer Ind/AK Nat-Male)'
AM02F05		'Students (2nd-Amer Ind/AK Nat-Female)'
AM02U05		'Students (2nd-Amer Ind/AK Nat-Unk)'
AS02M05		'Students (2nd-Asian/Pac Isl-Male)'
AS02F05		'Students (2nd-Asian/Pac Isl-Female)'
AS02U05		'Students (2nd-Asian/Pac Isl-Unknown)'
HI02M05		'Students (2nd-Hispanic-Male)'
HI02F05		'Students (2nd-Hispanic-Female)'
HI02U05		'Students (2nd-Hispanic-Unknown)'
BL02M05		'Students (2nd-Black-Male)'
BL02F05		'Students (2nd-Black-Female)'
BL02U05		'Students (2nd-Black-Unknown)'
WH02M05		'Students (2nd-White-Male)'
WH02F05		'Students (2nd-White-Female)'
WH02U05		'Students (2nd-White-Unknown)'
G0305			'Students (Total 3rd Grade)'
AM03M05		'Students (3rd-Amer Ind/AK Nat-Male)'
AM03F05		'Students (3rd-Amer Ind/AK Nat-Female)'
AM03U05		'Students (3rd-Amer Ind/AK Nat-Unk)'
AS03M05		'Students (3rd-Asian/Pac Isl-Male)'
AS03F05		'Students (3rd-Asian/Pac Isl-Female)'
AS03U05		'Students (3rd-Asian/Pac Isl-Unknown)'
HI03M05		'Students (3rd-Hispanic-Male)'
HI03F05		'Students (3rd-Hispanic-Female)'
HI03U05		'Students (3rd-Hispanic-Unknown)'
BL03M05		'Students (3rd-Black-Male)'
BL03F05		'Students (3rd-Black-Female)'
BL03U05		'Students (3rd-Black-Unknown)'
WH03M05		'Students (3rd-White-Male)'
WH03F05		'Students (3rd-White-Female)'
WH03U05		'Students (3rd-White-Unknown)'
G0405			'Students (Total 4th Grade)'
AM04M05		'Students (4th-Amer Ind/AK Nat-Male)'
AM04F05		'Students (4th-Amer Ind/AK Nat-Female)'
AM04U05		'Students (4th-Amer Ind/AK Nat-Unk)'
AS04M05		'Students (4th-Asian/Pac Isl-Male)'
AS04F05		'Students (4th-Asian/Pac Isl-Female)'
AS04U05		'Students (4th-Asian/Pac Isl-Unknown)'
HI04M05		'Students (4th-Hispanic-Male)'
HI04F05		'Students (4th-Hispanic-Female)'
HI04U05		'Students (4th-Hispanic-Unknown)'
BL04M05		'Students (4th-Black-Male)'
BL04F05		'Students (4th-Black-Female)'
BL04U05		'Students (4th-Black-Unknown)'
WH04M05		'Students (4th-White-Male)'
WH04F05		'Students (4th-White-Female)'
WH04U05		'Students (4th-White-Unknown)'
G0505			'Students (Total 5th Grade)'
AM05M05		'Students (5th-Amer Ind/AK Nat-Male)'
AM05F05		'Students (5th-Amer Ind/AK Nat-Female)'
AM05U05		'Students (5th-Amer Ind/AK Nat-Unknown)'
AS05M05		'Students (5th-Asian/Pac Isl-Male)'
AS05F05		'Students (5th-Asian/Pac Isl-Female)'
AS05U05		'Students (5th-Asian/Pac Isl-Unknown)'
HI05M05		'Students (5th-Hispanic-Male)'
HI05F05		'Students (5th-Hispanic-Female)'
HI05U05		'Students (5th-Hispanic-Unknown)'
BL05M05		'Students (5th-Black-Male)'
BL05F05		'Students (5th-Black-Female)'
BL05U05		'Students (5th-Black-Unknown)'
WH05M05		'Students (5th-White-Male)'
WH05F05		'Students (5th-White-Female)'
WH05U05		'Students (5th-White-Unknown)'
G0605			'Students (Total 6th Grade)'
AM06M05		'Students (6th-Amer Ind/AK Nat-Male)'
AM06F05		'Students (6th-Amer Ind/AK Nat-Female)'
AM06U05		'Students (6th-Amer Ind/AK Nat-Unknown)'
AS06M05		'Students (6th-Asian/Pac Isl-Male)'
AS06F05		'Students (6th-Asian/Pac Isl-Female)'
AS06U05		'Students (6th-Asian/Pac Isl-Unknown)'
HI06M05		'Students (6th-Hispanic-Male)'
HI06F05		'Students (6th-Hispanic-Female)'
HI06U05		'Students (6th-Hispanic-Unknown)'
BL06M05		'Students (6th-Black-Male)'
BL06F05		'Students (6th-Black-Female)'
BL06U05		'Students (6th-Black-Unknown)'
WH06M05		'Students (6th-White-Male)'
WH06F05		'Students (6th-White-Female)'
WH06U05		'Students (6th-White-Unknown)'
G0705			'Students (Total 7th Grade)'
AM07M05		'Students (7th-Amer Ind/AK Nat-Male)'
AM07F05		'Students (7th-Amer Ind/AK Nat-Female)'
AM07U05		'Students (7th-Amer Ind/AK Nat-Unknown)'
AS07M05		'Students (7th-Asian/Pac Isl-Male)'
AS07F05		'Students (7th-Asian/Pac Isl-Female)'
AS07U05		'Students (7th-Asian/Pac Isl-Unknown)'
HI07M05		'Students (7th-Hispanic-Male)'
HI07F05		'Students (7th-Hispanic-Female)'
HI07U05		'Students (7th-Hispanic-Unknown)'
BL07M05		'Students (7th-Black-Male)'
BL07F05		'Students (7th-Black-Female)'
BL07U05		'Students (7th-Black-Unknown)'
WH07M05		'Students (7th-White-Male)'
WH07F05		'Students (7th-White-Female)'
WH07U05		'Students (7th-White-Unknown)'
G0805			'Students (Total 8th Grade)'
AM08M05		'Students (8th-Amer Ind/AK Nat-Male)'
AM08F05		'Students (8th-Amer Ind/AK Nat-Female)'
AM08U05		'Students (8th-Amer Ind/AK Nat-Unk)'
AS08M05		'Students (8th-Asian/Pac Isl-Male)'
AS08F05		'Students (8th-Asian/Pac Isl-Female)'
AS08U05		'Students (8th-Asian/Pac Isl-Unknown)'
HI08M05		'Students (8th-Hispanic-Male)'
HI08F05		'Students (8th-Hispanic-Female)'
HI08U05		'Students (8th-Hispanic-Unknown)'
BL08M05		'Students (8th-Black-Male)'
BL08F05		'Students (8th-Black-Female)'
BL08U05		'Students (8th-Black-Unknown)'
WH08M05		'Students (8th-White-Male)'
WH08F05		'Students (8th-White-Female)'
WH08U05		'Students (8th-White-Unknown)'
G0905			'Students (Total 9th Grade)'
AM09M05		'Students (9th-Amer Ind/AK Nat-Male)'
AM09F05		'Students (9th-Amer Ind/AK Nat-Female)'
AM09U05		'Students (9th-Amer Ind/AK Nat-Unk)'
AS09M05		'Students (9th-Asian/Pac Isl-Male)'
AS09F05		'Students (9th-Asian/Pac Isl-Female)'
AS09U05		'Students (9th-Asian/Pac Isl-Unknown)'
HI09M05		'Students (9th-Hispanic-Male)'
HI09F05		'Students (9th-Hispanic-Female)'
HI09U05		'Students (9th-Hispanic-Unknown)'
BL09M05		'Students (9th-Black-Male)'
BL09F05		'Students (9th-Black-Female)'
BL09U05		'Students (9th-Black-Unknown)'
WH09M05		'Students (9th-White-Male)'
WH09F05		'Students (9th-White-Female)'
WH09U05		'Students (9th-White-Unknown)'
G1005			'Students (Total 10th Grade)'
AM10M05		'Students (10th-Amer Ind/AK Nat-Male)'
AM10F05		'Students (10th-Amer Ind/AK Nat-Female)'
AM10U05		'Students (10th-Amer Ind/AK Nat-Unk)'
AS10M05		'Students (10th-Asian/Pac Isl-Male)'
AS10F05		'Students (10th-Asian/Pac Isl-Female)'
AS10U05		'Students (10th-Asian/Pac Isl-Unknown)'
HI10M05		'Students (10th-Hispanic-Male)'
HI10F05		'Students (10th-Hispanic-Female)'
HI10U05		'Students (10th-Hispanic-Unknown)'
BL10M05		'Students (10th-Black-Male)'
BL10F05		'Students (10th-Black-Female)'
BL10U05		'Students (10th-Black-Unknown)'
WH10M05		'Students (10th-White-Male)'
WH10F05		'Students (10th-White-Female)'
WH10U05		'Students (10th-White-Unknown)'
G1105			'Students (Total 11th Grade)'
AM11M05		'Students (11th-Amer Ind/AK Nat-Male)'
AM11F05		'Students (11th-Amer Ind/AK Nat-Female)'
AM11U05		'Students (11th-Amer Ind/AK Nat-Unk)'
AS11M05		'Students (11th-Asian/Pac Isl-Male)'
AS11F05		'Students (11th-Asian/Pac Isl-Female)'
AS11U05		'Students (11th-Asian/Pac Isl-Unknown)'
HI11M05		'Students (11th-Hispanic-Male)'
HI11F05		'Students (11th-Hispanic-Female)'
HI11U05		'Students (11th-Hispanic-Unknown)'
BL11M05		'Students (11th-Black-Male)'
BL11F05		'Students (11th-Black-Female)'
BL11U05		'Students (11th-Black-Unknown)'
WH11M05		'Students (11th-White-Male)'
WH11F05		'Students (11th-White-Female)'
WH11U05		'Students (11th-White-Unknown)'
G1205			'Students (Total 12th Grade)'
AM12M05		'Students (12th-Amer Ind/AK Nat-Male)'
AM12F05		'Students (12th-Amer Ind/AK Nat-Female)'
AM12U05		'Students (12th-Amer Ind/AK Nat-Unk)'
AS12M05		'Students (12th-Asian/Pac Isl-Male)'
AS12F05		'Students (12th-Asian/Pac Isl-Female)'
AS12U05		'Students (12th-Asian/Pac Isl-Unknown)'
HI12M05		'Students (12th-Hispanic-Male)'
HI12F05		'Students (12th-Hispanic-Female)'
HI12U05		'Students (12th-Hispanic-Unknown)'
BL12M05		'Students (12th-Black-Male)'
BL12F05		'Students (12th-Black-Female)'
BL12U05		'Students (12th-Black-Unknown)'
WH12M05		'Students (12th-White-Male)'
WH12F05		'Students (12th-White-Female)'
WH12U05		'Students (12th-White-Unknown)'
UG05			'Students (Total Ungraded)'
AMUGM05		'Students (Ungr-Amer Ind/AK Nat-Male)'
AMUGF05		'Students (Ungr-Amer Ind/AK Nat-Female)'
AMUGU05		'Students (Ungr-Amer Ind/AK Nat-Unk)'
ASUGM05		'Students (Ungr-Asian/Pac Isl-Male)'
ASUGF05		'Students (Ungr-Asian/Pac Isl-Female)'
ASUGU05		'Students (Ungr-Asian/Pac Isl-Unknown)'
HIUGM05		'Students (Ungr-Hispanic-Male)'
HIUGF05		'Students (Ungr-Hispanic-Female)'
HIUGU05		'Students (Ungr-Hispanic-Unknown)'
BLUGM05		'Students (Ungr-Black-Male)'
BLUGF05		'Students (Ungr-Black-Female)'
BLUGU05		'Students (Ungr-Black-Unknown)'
WHUGM05		'Students (Ungr-White-Male)'
WHUGF05		'Students (Ungr-White-Female)'
WHUGU05		'Students (Ungr-White-Unknown)'
MEMBER05		'Students (Total Reported Membership)'
AM05			'Am Indian/Alaskan Students'
AMALM05		'Students (Tot-Amer Ind/AK Nat-Male)'
AMALF05		'Students (Tot-Amer Ind/AK NatFemale)'
AMALU05		'Students (Tot-Amer Ind/AK NatUnk)'
ASIAN05		'Asian/Pacific Islander Students'
ASALM05		'Students (Tot-Asian/Pac Isl-Male)'
ASALF05		'Students (Tot-Asian/Pac Isl-Female)'
ASALU05		'Students (Tot-Asian/Pac Isl-Unknown)'
HISP05		'Hispanic Students'
HIALM05		'Students (Tot-Hispanic-Male)'
HIALF05		'Students (Tot-Hispanic-Female)'
HIALU05		'Students (Tot-Hispanic-Unknown)'
BLACK05		'Black Non-Hispanic Students'
BLALM05		'Students (Tot-Black-Male)'
BLALF05		'Students (Tot-Black-Female)'
BLALU05		'Students (Tot-Black-Unknown)'
WHITE05		'White Non-Hispanic Students'
WHALM05		'Students (Tot-White-Male)'
WHALF05		'Students (Tot-White-Female)'
WHALU05		'Students (Tot-White-Unknown)'
TOTETH05		'Total Ethnic'
PUPTCH05		'Pupil Teacher Ratio'
TOTGRD05		'Students (Total Calculated Membership)'
ILOCAL05		'Locale Code Adj Flag'
IFTE05		'Teachers Adj Flag'
IGSLO05		'School Low Grade Offered Adj Flag'
IGSHI05		'School High Grade Offered Adj Flag'
ITITLI05		'Title I Eligible School Adj Flag'
ISTITL05		'School-wide Title I Adj Flag'
IMAGNE05		'Magnet School Adj Flag'
ICHART05		'Charter School Adj Flag'
ISHARE05		'Shared-time School Adj Flag'
IFRELC05		'Free Lunch Eligible Adj Flag'
IREDLC05		'Red-price Lunch El. Adj Flag'
ITOTFR05		'Total Free and Red Adj Flag'
IMIGRN05		'Migrant Students Adj Flag'
IPK05			'Total PK Students Adj Flag'
IAMPKM05		'PK-Amer Ind/AK Nat-Male Adj Flag'
IAMPKF05		'PK-Amer Ind/AK Nat-Fem Adj Flag'
IAMPKU05		'PK-Amer Ind/AK Nat-Unkn Adj Flag'
IASPKM05		'PK-Asian/Pac Isl-Male Adj Flag'
IASPKF05		'PK-Asian/Pac Isl-Fem Adj Flag'
IASPKU05		'PK-Asian/Pac Isl-Unkn Adj Flag'
IHIPKM05		'PK-Hispanic-Male Adj Flag'
IHIPKF05		'PK-Hispanic-Fem Adj Flag'
IHIPKU05		'PK-Hispanic-Unkn Adj Flag'
IBLPKM05		'PK-Black-Male Adj Flag'
IBLPKF05		'PK-Black-Fem Adj Flag'
IBLPKU05		'PK-Black-Unkn Adj Flag'
IWHPKM05		'PK-White-Male Adj Flag'
IWHPKF05		'PK-White-Fem Adj Flag'
IWHPKU05		'PK-White-Unkn Adj Flag'
IKG05			'Total KG Students Adj Flag'
IAMKGM05		'KG-Amer Ind/AK Nat-Male Adj Flag'
IAMKGF05		'KG-Amer Ind/AK Nat-Fem Adj Flag'
IAMKGU05		'KG-Amer Ind/AK Nat-Unkn Adj Flag'
IASKGM05		'KG-Asian/Pac Isl-Male Adj Flag'
IASKGF05		'KG-Asian/Pac Isl-Fem Adj Flag'
IASKGU05		'KG-Asian/Pac Isl-Unkn Adj Flag'
IHIKGM05		'KG-Hispanic-Male Adj Flag'
IHIKGF05		'KG-Hispanic-Fem Adj Flag'
IHIKGU05		'KG-Hispanic-Unkn Adj Flag'
IBLKGM05		'KG-Black-Male Adj Flag'
IBLKGF05		'KG-Black-Fem Adj Flag'
IBLKGU05		'KG-Black-Unkn Adj Flag'
IWHKGM05		'KG-White-Male Adj Flag'
IWHKGF05		'KG-White-Fem Adj Flag'
IWHKGU05		'KG-White-Unkn Adj Flag'
IG0105		'Total 1st Grade Students Adj Flag'
IAM01M05		'1st-Amer Ind/AK Nat-Male Adj Flag'
IAM01F05		'1st-Amer Ind/AK Nat-Fem Adj Flag'
IAM01U05		'1st-Amer Ind/AK Nat-Unkn Adj Flag'
IAS01M05		'1st-Asian/Pac Isl-Male Adj Flag'
IAS01F05		'1st-Asian/Pac Isl-Fem Adj Flag'
IAS01U05		'1st-Asian/Pac Isl-Unkn Adj Flag'
IHI01M05		'1st-Hispanic-Male Adj Flag'
IHI01F05		'1st-Hispanic-Fem Adj Flag'
IHI01U05		'1st-Hispanic-Unkn Adj Flag'
IBL01M05		'1st-Black-Male Adj Flag'
IBL01F05		'1st-Black-Fem Adj Flag'
IBL01U05		'1st-Black-Unkn Adj Flag'
IWH01M05		'1st-White-Male Adj Flag'
IWH01F05		'1st-White-Fem Adj Flag'
IWH01U05		'1st-White-Unkn Adj Flag'
IG0205		'Total 2nd Grade Students Adj Flag'
IAM02M05		'2nd-Amer Ind/AK Nat-Male Adj Flag'
IAM02F05		'2nd-Amer Ind/AK Nat-Fem Adj Flag'
IAM02U05		'2nd-Amer Ind/AK Nat-Unkn Adj Flag'
IAS02M05		'2nd-Asian/Pac Isl-Male Adj Flag'
IAS02F05		'2nd-Asian/Pac Isl-Fem Adj Flag'
IAS02U05		'2nd-Asian/Pac Isl-Unkn Adj Flag'
IHI02M05		'2nd-Hispanic-Male Adj Flag'
IHI02F05		'2nd-Hispanic-Fem Adj Flag'
IHI02U05		'2nd-Hispanic-Unkn Adj Flag'
IBL02M05		'2nd-Black-Male Adj Flag'
IBL02F05		'2nd-Black-Fem Adj Flag'
IBL02U05		'2nd-Black-Unkn Adj Flag'
IWH02M05		'2nd-White-Male Adj Flag'
IWH02F05		'2nd-White-Fem Adj Flag'
IWH02U05		'2nd-White-Unkn Adj Flag'
IG0305		'Total 3rd Grade Students Adj Flag'
IAM03M05		'3rd-Amer Ind/AK Nat-Male Adj Flag'
IAM03F05		'3rd-Amer Ind/AK Nat-Fem Adj Flag'
IAM03U05		'3rd-Amer Ind/AK Nat-Unkn Adj Flag'
IAS03M05		'3rd-Asian/Pac Isl-Male Adj Flag'
IAS03F05		'3rd-Asian/Pac Isl-Fem Adj Flag'
IAS03U05		'3rd-Asian/Pac Isl-Unkn Adj Flag'
IHI03M05		'3rd-Hispanic-Male Adj Flag'
IHI03F05		'3rd-Hispanic-Fem Adj Flag'
IHI03U05		'3rd-Hispanic-Unkn Adj Flag'
IBL03M05		'3rd-Black-Male Adj Flag'
IBL03F05		'3rd-Black-Fem Adj Flag'
IBL03U05		'3rd-Black-Unkn Adj Flag'
IWH03M05		'3rd-White-Male Adj Flag'
IWH03F05		'3rd-White-Fem Adj Flag'
IWH03U05		'3rd-White-Unkn Adj Flag'
IG0405		'Total 4th Grade Students Adj Flag'
IAM04M05		'4th-Amer Ind/AK Nat-Male Adj Flag'
IAM04F05		'4th-Amer Ind/AK Nat-Fem Adj Flag'
IAM04U05		'4th-Amer Ind/AK Nat-Unkn Adj Flag'
IAS04M05		'4th-Asian/Pac Isl-Male Adj Flag'
IAS04F05		'4th-Asian/Pac Isl-Fem Adj Flag'
IAS04U05		'4th-Asian/Pac Isl-Unkn Adj Flag'
IHI04M05		'4th-Hispanic-Male Adj Flag'
IHI04F05		'4th-Hispanic-Fem Adj Flag'
IHI04U05		'4th-Hispanic-Unkn Adj Flag'
IBL04M05		'4th-Black-Male Adj Flag'
IBL04F05		'4th-Black-Fem Adj Flag'
IBL04U05		'4th-Black-Unkn Adj Flag'
IWH04M05		'4th-White-Male Adj Flag'
IWH04F05		'4th-White-Fem Adj Flag'
IWH04U05		'4th-White-Unkn Adj Flag'
IG0505		'Total 5th Grade Students Adj Flag'
IAM05M05		'5th-Amer Ind/AK Nat-Male Adj Flag'
IAM05F05		'5th-Amer Ind/AK Nat-Fem Adj Flag'
IAM05U05		'5th-Amer Ind/AK Nat-Unkn Adj Flag'
IAS05M05		'5th-Asian/Pac Isl-Male Adj Flag'
IAS05F05		'5th-Asian/Pac Isl-Fem Adj Flag'
IAS05U05		'5th-Asian/Pac Isl-Unkn Adj Flag'
IHI05M05		'5th-Hispanic-Male Adj Flag'
IHI05F05		'5th-Hispanic-Fem Adj Flag'
IHI05U05		'5th-Hispanic-Unkn Adj Flag'
IBL05M05		'5th-Black-Male Adj Flag'
IBL05F05		'5th-Black-Fem Adj Flag'
IBL05U05		'5th-Black-Unkn Adj Flag'
IWH05M05		'5th-White-Male Adj Flag'
IWH05F05		'5th-White-Fem Adj Flag'
IWH05U05		'5th-White-Unkn Adj Flag'
IG0605			'Total 6th Grade Students Adj Flag'
IAM06M05		'6th-Amer Ind/AK Nat-Male Adj Flag'
IAM06F05		'6th-Amer Ind/AK Nat-Fem Adj Flag'
IAM06U05		'6th-Amer Ind/AK Nat-Unkn Adj Flag'
IAS06M05		'6th-Asian/Pac Isl-Male Adj Flag'
IAS06F05		'6th-Asian/Pac Isl-Fem Adj Flag'
IAS06U05		'6th-Asian/Pac Isl-Unkn Adj Flag'
IHI06M05		'6th-Hispanic-Male Adj Flag'
IHI06F05		'6th-Hispanic-Fem Adj Flag'
IHI06U05		'6th-Hispanic-Unkn Adj Flag'
IBL06M05		'6th-Black-Male Adj Flag'
IBL06F05		'6th-Black-Fem Adj Flag'
IBL06U05		'6th-Black-Unkn Adj Flag'
IWH06M05		'6th-White-Male Adj Flag'
IWH06F05		'6th-White-Fem Adj Flag'
IWH06U05		'6th-White-Unkn Adj Flag'
IG0705			'Total 7th Grade Students Adj Flag'
IAM07M05		'7th-Amer Ind/AK Nat-Male Adj Flag'
IAM07F05		'7th-Amer Ind/AK Nat-Fem Adj Flag'
IAM07U05		'7th-Amer Ind/AK Nat-Unkn Adj Flag'
IAS07M05		'7th-Asian/Pac Isl-Male Adj Flag'
IAS07F05		'7th-Asian/Pac Isl-Fem Adj Flag'
IAS07U05		'7th-Asian/Pac Isl-Unkn Adj Flag'
IHI07M05		'7th-Hispanic-Male Adj Flag'
IHI07F05		'7th-Hispanic-Fem Adj Flag'
IHI07U05		'7th-Hispanic-Unkn Adj Flag'
IBL07M05		'7th-Black-Male Adj Flag'
IBL07F05		'7th-Black-Fem Adj Flag'
IBL07U05		'7th-Black-Unkn Adj Flag'
IWH07M05		'7th-White-Male Adj Flag'
IWH07F05		'7th-White-Fem Adj Flag'
IWH07U05		'7th-White-Unkn Adj Flag'
IG0805			'Total 8th Grade Students Adj Flag'
IAM08M05		'8th-Amer Ind/AK Nat-Male Adj Flag'
IAM08F05		'8th-Amer Ind/AK Nat-Fem Adj Flag'
IAM08U05		'8th-Amer Ind/AK Nat-Unkn Adj Flag'
IAS08M05		'8th-Asian/Pac Isl-Male Adj Flag'
IAS08F05		'8th-Asian/Pac Isl-Fem Adj Flag'
IAS08U05		'8th-Asian/Pac Isl-Unkn Adj Flag'
IHI08M05		'8th-Hispanic-Male Adj Flag'
IHI08F05		'8th-Hispanic-Fem Adj Flag'
IHI08U05		'8th-Hispanic-Unkn Adj Flag'
IBL08M05		'8th-Black-Male Adj Flag'
IBL08F05		'8th-Black-Fem Adj Flag'
IBL08U05		'8th-Black-Unkn Adj Flag'
IWH08M05		'8th-White-Male Adj Flag'
IWH08F05		'8th-White-Fem Adj Flag'
IWH08U05		'8th-White-Unkn Adj Flag'
IG0905			'Total 9th Grade Students Adj Flag'
IAM09M05		'9th-Amer Ind/AK Nat-Male Adj Flag'
IAM09F05		'9th-Amer Ind/AK Nat-Fem Adj Flag'
IAM09U05		'9th-Amer Ind/AK Nat-Unkn Adj Flag'
IAS09M05		'9th-Asian/Pac Isl-Male Adj Flag'
IAS09F05		'9th-Asian/Pac Isl-Fem Adj Flag'
IAS09U05		'9th-Asian/Pac Isl-Unkn Adj Flag'
IHI09M05		'9th-Hispanic-Male Adj Flag'
IHI09F05		'9th-Hispanic-Fem Adj Flag'
IHI09U05		'9th-Hispanic-Unkn Adj Flag'
IBL09M05		'9th-Black-Male Adj Flag'
IBL09F05		'9th-Black-Fem Adj Flag'
IBL09U05		'9th-Black-Unkn Adj Flag'
IWH09M05		'9th-White-Male Adj Flag'
IWH09F05		'9th-White-Fem Adj Flag'
IWH09U05		'9th-White-Unkn Adj Flag'
IG1005			'Total 10th Grade Students Adj Flag'
IAM10M05		'10th-Amer Ind/AK Nat-Male Adj Flag'
IAM10F05		'10th-Amer Ind/AK Nat-Fem Adj Flag'
IAM10U05		'10th-Amer Ind/AK Nat-Unkn Adj Flag'
IAS10M05		'10th-Asian/Pac Isl-Male Adj Flag'
IAS10F05		'10th-Asian/Pac Isl-Fem Adj Flag'
IAS10U05		'10th-Asian/Pac Isl-Unkn Adj Flag'
IHI10M05		'10th-Hispanic-Male Adj Flag'
IHI10F05		'10th-Hispanic-Fem Adj Flag'
IHI10U05		'10th-Hispanic-Unkn Adj Flag'
IBL10M05		'10th-Black-Male Adj Flag'
IBL10F05		'10th-Black-Fem Adj Flag'
IBL10U05		'10th-Black-Unkn Adj Flag'
IWH10M05		'10th-White-Male Adj Flag'
IWH10F05		'10th-White-Fem Adj Flag'
IWH10U05		'10th-White-Unkn Adj Flag'
IG1105			'Total 11th Grade Students Adj Flag'
IAM11M05		'11th-Amer Ind/AK Nat-Male Adj Flag'
IAM11F05		'11th-Amer Ind/AK Nat-Fem Adj Flag'
IAM11U05		'11th-Amer Ind/AK Nat-Unkn Adj Flag'
IAS11M05		'11th-Asian/Pac Isl-Male Adj Flag'
IAS11F05		'11th-Asian/Pac Isl-Fem Adj Flag'
IAS11U05		'11th-Asian/Pac Isl-Unkn Adj Flag'
IHI11M05		'11th-Hispanic-Male Adj Flag'
IHI11F05		'11th-Hispanic-Fem Adj Flag'
IHI11U05		'11th-Hispanic-Unkn Adj Flag'
IBL11M05		'11th-Black-Male Adj Flag'
IBL11F05		'11th-Black-Fem Adj Flag'
IBL11U05		'11th-Black-Unkn Adj Flag'
IWH11M05		'11th-White-Male Adj Flag'
IWH11F05		'11th-White-Fem Adj Flag'
IWH11U05		'11th-White-Unkn Adj Flag'
IG1205			'Total 12th Grade Students Adj Flag'
IAM12M05		'12th-Amer Ind/AK Nat-Male Adj Flag'
IAM12F05		'12th-Amer Ind/AK Nat-Fem Adj Flag'
IAM12U05		'12th-Amer Ind/AK Nat-Unkn Adj Flag'
IAS12M05		'12th-Asian/Pac Isl-Male Adj Flag'
IAS12F05		'12th-Asian/Pac Isl-Fem Adj Flag'
IAS12U05		'12th-Asian/Pac Isl-Unkn Adj Flag'
IHI12M05		'12th-Hispanic-Male Adj Flag'
IHI12F05		'12th-Hispanic-Fem Adj Flag'
IHI12U05		'12th-Hispanic-Unkn Adj Flag'
IBL12M05		'12th-Black-Male Adj Flag'
IBL12F05		'12th-Black-Fem Adj Flag'
IBL12U05		'12th-Black-Unkn Adj Flag'
IWH12M05		'12th-White-Male Adj Flag'
IWH12F05		'12th-White-Fem Adj Flag'
IWH12U05		'12th-White-Unkn Adj Flag'
IUG05			'Total Ungraded Students Adj Flag'
IAMUGM05		'Ungr-Amer Ind/AK Nat-Male Adj Flag'
IAMUGF05		'Ungr-Amer Ind/AK Nat-Fem Adj Flag'
IAMUGU05		'Ungr-Amer Ind/AK Nat-Unkn Adj Flag'
IASUGM05		'Ungr-Asian/Pac Isl-Male Adj Flag'
IASUGF05		'Ungr-Asian/Pac Isl-Fem Adj Flag'
IASUGU05		'Ungr-Asian/Pac Isl-Unkn Adj Flag'
IHIUGM05		'Ungr-Hispanic-Male Adj Flag'
IHIUGF05		'Ungr-Hispanic-Fem Adj Flag'
IHIUGU05		'Ungr-Hispanic-Unkn Adj Flag'
IBLUGM05		'Ungr-Black-Male Adj Flag'
IBLUGF05		'Ungr-Black-Fem Adj Flag'
IBLUGU05		'Ungr-Black-Unkn Adj Flag'
IWHUGM05		'Ungr-White-Male Adj Flag'
IWHUGF05		'Ungr-White-Fem Adj Flag'
IWHUGU05		'Ungr-White-Unkn Adj Flag'
IMEMB05		'Total Reported Membership Adj Flag'
IAM05			'Am Indian/Alaskan Stu Adj Flag'
IAMALM05		'Tot-Amer Ind/AK Nat-Male Adj Flag'
IAMALF05		'Tot-Amer Ind/AK Nat-Fem Adj Flag'
IAMALU05		'Tot-Amer Ind/AK Nat-Unkn Adj Flag'
IASIAN05		'Asian/Pac Islander Stu Adj Flag'
IASALM05		'Tot-Asian/Pac Isl-Male Adj Flag'
IASALF05		'Tot-Asian/Pac Isl-Fem Adj Flag'
IASALU05		'Tot-Asian/Pac Isl-Unkn Adj Flag'
IHISP05		'Hispanic Stu Adj Flag'
IHIALM05		'Tot-Hispanic-Male Adj Flag'
IHIALF05		'Tot-Hispanic-Fem Adj Flag'
IHIALU05		'Tot-Hispanic-Unkn Adj Flag'
IBLACK05		'Black Non-Hispanic Stu Adj Flag'
IBLALM05		'Tot-Black-Male Adj Flag'
IBLALF05		'Tot-Black-Fem Adj Flag'
IBLALU05		'Tot-Black-Unkn Adj Flag'
IWHITE05		'White Non-Hispanic Stu Adj Flag'
IWHALM05		'Tot-White-Male Adj Flag'
IWHALF05		'Tot-White-Fem Adj Flag'
IWHALU05		'Tot-White-Unkn Adj Flag'
IETH05		'Total Ethnicity Adj Flag'
IPUTCH05		'Pupil Teacher Ratio Adj Flag'
ITOTGR05		'Total Calculated Membership Adj Flag'
.
VALUE LABELS
/Fipst
'01'  	'Alabama'
'02'  	'Alaska'
'04'  	'Arizona'
'05'  	'Arkansas'
'06'  	'California'
'08'  	'Colorado'
'09'  	'Connecticut'
'10'  	'Delaware'
'11'  	'District of Columbia'
'12'  	'Florida'
'13'  	'Georgia'
'15'  	'Hawaii'
'16'  	'Idaho'
'17'  	'Illinois'
'18'  	'Indiana'
'19'  	'Iowa'
'20'  	'Kansas'
'21'  	'Kentucky'
'22'  	'Louisiana'
'23'  	'Maine'
'24'  	'Maryland'
'25'  	'Massachusetts'
'26'  	'Michigan'
'27'  	'Minnesota'
'28'  	'Mississippi'
'29'  	'Missouri'
'30'  	'Montana'
'31'  	'Nebraska'
'32'  	'Nevada'
'33'  	'New Hampshire'
'34'  	'New Jersey'
'35'  	'New Mexico'
'36'  	'New York'
'37'  	'North Carolina'
'38'  	'North Dakota'
'39'  	'Ohio'
'40'  	'Oklahoma'
'41'  	'Oregon'
'42'  	'Pennsylvania'
'44'  	'Rhode Island'
'45'  	'South Carolina'
'46'  	'South Dakota'
'47'  	'Tennessee'
'48'  	'Texas'
'49'  	'Utah'
'50'  	'Vermont'
'51'  	'Virginia'
'53'  	'Washington'
'54'  	'West Virginia'
'55'  	'Wisconsin'
'56'  	'Wyoming'
'58'  	'DOD Schools (overseas)'
'59'  	'Bureau of Indian Affairs'
'60'  	'American Samoa'
'61'  	'DOD Schools (domestic)'
'66'  	'Guam'
'69'  	'Northern Marianas'
'72'  	'Puerto Rico'
'78'  	'Virgin Islands'
'M'   	'Missing'
'N'   	'Not Applicable'
/Type05
'1'  		'Regular School'
'2'  		'Special education School'
'3'  		'Vocational School'
'4'  		'Other/alternative School'
'M'  		'Missing'
'N'  		'Not Applicable'
/Status05
'1'  		'Open - in operation from the last report'
'2'  		'Closed - since last report'
'3'  		'New - opened since last report'
'4'  		'Added - open during PY but not reported'
'5'  		'Changed Agency - affiliated w/ diff. agency PY'
'6'  		'Inactive - temporarily closed'
'7'  		'Future School - scheduled to open within 2 years'
'8'		'Reopened - closed in PY and reopened in CY'
'M'  		'Missing'
'N'  		'Not Applicable'
/Locale05
'1'  		'Large Central City'
'2'  		'Mid-size Central City'
'3'  		'Urban Fringe of Large City'
'4'  		'Urban Fringe of Mid-size City'
'5'  		'Large Town'
'6'  		'Small Town'
'7'  		'Rural, outside CBSA'
'8'  		'Rural, inside CBSA'
'M'  		'Missing'
'N'  		'Not Applicable'
/Inout05
'1'  		'Inside the city/town limits'
'2'  		'Outside the city/town limits'
'M'  		'Missing'
'N'  		'Not Applicable'
/Gslo05
'01'  	'1st Grade'
'02'  	'2nd Grade'
'03'  	'3rd Grade'
'04'  	'4th Grade'
'05'  	'5th Grade'
'06'  	'6th Grade'
'07'  	'7th Grade'
'08'  	'8th Grade'
'09'  	'9th Grade'
'10'  	'10th Grade'
'11'  	'11th Grade'
'12'  	'12th Grade'
'KG'  	'Kindergarten'
'M'   	'Missing'
'N'   	'NA/No Students Reported'
'PK'  	'PreKindergarten'
'UG'  	'Ungraded'
/Gshi05
'01'  	'1st Grade'
'02'  	'2nd Grade'
'03'  	'3rd Grade'
'04'  	'4th Grade'
'05'  	'5th Grade'
'06'  	'6th Grade'
'07'  	'7th Grade'
'08'  	'8th Grade'
'09'  	'9th Grade'
'10'  	'10th Grade'
'11'  	'11th Grade'
'12'  	'12th Grade'
'KG'  	'Kindergarten'
'M'   	'Missing'
'N'   	'NA/No Students Reported'
'PK'  	'PreKindergarten'
'UG'  	'Ungraded'
/Level05
'1'   	'Primary School'
'2'   	'Middle School'
'3'   	'High School'
'4'   	'Other'
'M'   	'Missing'
'N'   	'Not Applicable'
/TitleI05
'1'   	'Yes'
'2'   	'No'
'M'   	'Missing'
'N'   	'Not Applicable'
/StitlI05
'1'   	'Yes'
'2'   	'No'
'M'   	'Missing'
'N'   	'Not Applicable'
/Magnet05
'1'   	'Yes'
'2'   	'No'
'M'   	'Missing'
'N'   	'Not Applicable'
/Chartr05
'1'   	'Yes'
'2'   	'No'
'M'   	'Missing'
'N'   	'Not Applicable'
/ILOCAL05  IFTE05  IGSLO05 IGSHI05
ITITLI05  ISTITL05  IMAGNE05  ICHART05  ISHARE05  IFRELC05
IREDLC05  ITOTFR05  IMIGRN05  IPK05     IAMPKM05  IAMPKF05
IAMPKU05  IASPKM05  IASPKF05  IASPKU05  IHIPKM05  IHIPKF05
IHIPKU05  IBLPKM05  IBLPKF05  IBLPKU05  IWHPKM05  IWHPKF05
IWHPKU05  IKG05  	  IAMKGM05  IAMKGF05  IAMKGU05  IASKGM05
IASKGF05  IASKGU05  IHIKGM05  IHIKGF05  IHIKGU05  IBLKGM05
IBLKGF05  IBLKGU05  IWHKGM05  IWHKGF05  IWHKGU05  IG0105
IAM01M05  IAM01F05  IAM01U05  IAS01M05  IAS01F05  IAS01U05
IHI01M05  IHI01F05  IHI01U05  IBL01M05  IBL01F05  IBL01U05
IWH01M05  IWH01F05  IWH01U05  IG0205    IAM02M05  IAM02F05
IAM02U05  IAS02M05  IAS02F05  IAS02U05  IHI02M05  IHI02F05
IHI02U05  IBL02M05  IBL02F05  IBL02U05  IWH02M05  IWH02F05
IWH02U05  IG0305    IAM03M05  IAM03F05  IAM03U05  IAS03M05
IAS03F05  IAS03U05  IHI03M05  IHI03F05  IHI03U05  IBL03M05
IBL03F05  IBL03U05  IWH03M05  IWH03F05  IWH03U05  IG0405
IAM04M05  IAM04F05  IAM04U05  IAS04M05  IAS04F05  IAS04U05
IHI04M05  IHI04F05  IHI04U05  IBL04M05  IBL04F05  IBL04U05
IWH04M05  IWH04F05  IWH04U05  IG0505    IAM05M05  IAM05F05
IAM05U05  IAS05M05  IAS05F05  IAS05U05  IHI05M05  IHI05F05
IHI05U05  IBL05M05  IBL05F05  IBL05U05  IWH05M05  IWH05F05
IWH05U05  IG0605    IAM06M05  IAM06F05  IAM06U05  IAS06M05
IAS06F05  IAS06U05  IHI06M05  IHI06F05  IHI06U05  IBL06M05
IBL06F05  IBL06U05  IWH06M05  IWH06F05  IWH06U05  IG0705
IAM07M05  IAM07F05  IAM07U05  IAS07M05  IAS07F05  IAS07U05
IHI07M05  IHI07F05  IHI07U05  IBL07M05  IBL07F05  IBL07U05
IWH07M05  IWH07F05  IWH07U05  IG0805    IAM08M05  IAM08F05
IAM08U05  IAS08M05  IAS08F05  IAS08U05  IHI08M05  IHI08F05
IHI08U05  IBL08M05  IBL08F05  IBL08U05  IWH08M05  IWH08F05
IWH08U05  IG0905    IAM09M05  IAM09F05  IAM09U05  IAS09M05
IAS09F05  IAS09U05  IHI09M05  IHI09F05  IHI09U05  IBL09M05
IBL09F05  IBL09U05  IWH09M05  IWH09F05  IWH09U05  IG1005
IAM10M05  IAM10F05  IAM10U05  IAS10M05  IAS10F05  IAS10U05
IHI10M05  IHI10F05  IHI10U05  IBL10M05  IBL10F05  IBL10U05
IWH10M05  IWH10F05  IWH10U05  IG1105    IAM11M05  IAM11F05
IAM11U05  IAS11M05  IAS11F05  IAS11U05  IHI11M05  IHI11F05
IHI11U05  IBL11M05  IBL11F05  IBL11U05  IWH11M05  IWH11F05
IWH11U05  IG1205    IAM12M05  IAM12F05  IAM12U05  IAS12M05
IAS12F05  IAS12U05  IHI12M05  IHI12F05  IHI12U05  IBL12M05
IBL12F05  IBL12U05  IWH12M05  IWH12F05  IWH12U05  IUG05
IAMUGM05  IAMUGF05  IAMUGU05  IASUGM05  IASUGF05  IASUGU05
IHIUGM05  IHIUGF05  IHIUGU05  IBLUGM05  IBLUGF05  IBLUGU05
IWHUGM05  IWHUGF05  IWHUGU05  IMEMB05   IAM05  	  IAMALM05
IAMALF05  IAMALU05  IASIAN05  IASALM05  IASALF05  IASALU05
IHISP05   IHIALM05  IHIALF05  IHIALU05  IBLACK05  IBLALM05
IBLALF05  IBLALU05  IWHITE05  IWHALM05  IWHALF05  IWHALU05
IETH05    IPUTCH05  ITOTGR05
'A'    'Adjusted'
'C'    'Combined with Data Provided Elsewhere by the State'
'N'    'Not Applicable'	
'O'    'Locale Code Assigned Under Old Methodology'
'R'    'As Reported by the State'
'T'    'Total Based on Sum of Intenal or External Detail'	
'W'    'Locale Code Assigned Under New Methodology'
.
MISSING VALUES
FTE05 FRELCH05 TO TOTGRD05 (-1, -2).

SAVE OUTFILE sc051a/COMPRESSED.
GET FILE sc051a.
EXECUTE.
